GatingProjection
================

.. automodule:: psyneulink.core.components.projections.modulatory.gatingprojection
   :members:
   :private-members:
   :exclude-members: random, execute, Parameters
